@@ -1,5 +1,5 @@
 package App::Sets::Sort;
-$App::Sets::Sort::VERSION = '0.974';
+$App::Sets::Sort::VERSION = '0.976';
 
 
 use strict;
@@ -31,8 +31,10 @@ sub _test_external_sort {
       close $fh or die 'whatever';
    } or return;
 
-   open my $fh, '-|', 'sort', '-u', $filename or return;
-   return unless $fh;
+   my $fh = eval {
+      open my $tfh, '-|', 'sort', '-u', $filename;
+      $tfh;
+   } or return;
    my @lines = <$fh>;
    return unless scalar(@lines) == 4;
    return unless defined $lines[3];
@@ -164,7 +166,7 @@ App::Sets::Sort - sort handling
 
 =head1 VERSION
 
-version 0.974
+version 0.976
 
 =head1 AUTHOR
 
